# Installation | Установка

## Windows
```
pip install aiosmshub
```

## Linux
```
pip3 install aiosmshub
```



# Information | Информация
ENG: The current version of aiosmshub is 0.3.0
RU: Актуальная версия aiosmshub 0.3.0
Пока идет разработка, поэтому ничего нет :(
